==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerRuleConditionSourceIpArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property values List of header value patterns to match. Maximum size of each pattern is 128 characters. Comparison is case insensitive. Wildcard characters supported: * (matches 0 or more characters) and ? (matches exactly 1 character). If the same header appears multiple times in the request they will be searched in order until a match is found. Only one pattern needs to match for the condition to be satisfied. To require that all of the strings are a match, create one condition block per string.
 */
public data class ListenerRuleConditionSourceIpArgs(
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs =
        com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs.builder()
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ListenerRuleConditionSourceIpArgs].
 */
@PulumiTagMarker
public class ListenerRuleConditionSourceIpArgsBuilder internal constructor() {
    private var values: Output<List<String>>? = null

    /**
     * @param value List of header value patterns to match. Maximum size of each pattern is 128 characters. Comparison is case insensitive. Wildcard characters supported: * (matches 0 or more characters) and ? (matches exactly 1 character). If the same header appears multiple times in the request they will be searched in order until a match is found. Only one pattern needs to match for the condition to be satisfied. To require that all of the strings are a match, create one condition block per string.
     */
    @JvmName("bvsnoikuvwprbpfn")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("ofjvcjghrhlnepjf")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values List of header value patterns to match. Maximum size of each pattern is 128 characters. Comparison is case insensitive. Wildcard characters supported: * (matches 0 or more characters) and ? (matches exactly 1 character). If the same header appears multiple times in the request they will be searched in order until a match is found. Only one pattern needs to match for the condition to be satisfied. To require that all of the strings are a match, create one condition block per string.
     */
    @JvmName("tiryqnjyppsgtrww")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value List of header value patterns to match. Maximum size of each pattern is 128 characters. Comparison is case insensitive. Wildcard characters supported: * (matches 0 or more characters) and ? (matches exactly 1 character). If the same header appears multiple times in the request they will be searched in order until a match is found. Only one pattern needs to match for the condition to be satisfied. To require that all of the strings are a match, create one condition block per string.
     */
    @JvmName("yfqravobanksmxmk")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values List of header value patterns to match. Maximum size of each pattern is 128 characters. Comparison is case insensitive. Wildcard characters supported: * (matches 0 or more characters) and ? (matches exactly 1 character). If the same header appears multiple times in the request they will be searched in order until a match is found. Only one pattern needs to match for the condition to be satisfied. To require that all of the strings are a match, create one condition block per string.
     */
    @JvmName("lrynvxmeagejcuuo")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): ListenerRuleConditionSourceIpArgs = ListenerRuleConditionSourceIpArgs(
        values = values ?: throw PulumiNullFieldException("values"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/alb/kotlin/inputs/ListenerRuleConditionSourceIpArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.alb.kotlin.inputs

import com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property values
 */
public data class ListenerRuleConditionSourceIpArgs(
    public val values: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs> {
    override fun toJava(): com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs =
        com.pulumi.aws.alb.inputs.ListenerRuleConditionSourceIpArgs.builder()
            .values(values.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ListenerRuleConditionSourceIpArgs].
 */
@PulumiTagMarker
public class ListenerRuleConditionSourceIpArgsBuilder internal constructor() {
    private var values: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("recvfqwmhsfklmhp")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("hrmyahpsuvqenvim")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jixwohkbkshqyjhk")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("envstgonsijrpuwx")
    public suspend fun values(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values
     */
    @JvmName("uquhdqucxghmtuow")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): ListenerRuleConditionSourceIpArgs = ListenerRuleConditionSourceIpArgs(
        values = values ?: throw PulumiNullFieldException("values"),
    )
}
